@@ -1,12 +1,13 @@
 //! Type information structs for dynamic resources.
 use std::str::FromStr;
 
+use crate::TypeMeta;
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 
 #[derive(Debug, Error)]
 #[error("failed to parse group version: {0}")]
-/// Failed to parse group version.
+/// Failed to parse group version
 pub struct ParseGroupVersionError(pub String);
 
 /// Core information about an API Resource.
@@ -31,6 +32,21 @@ impl GroupVersionKind {
     }
 }
 
+impl TryFrom<&TypeMeta> for GroupVersionKind {
+    type Error = ParseGroupVersionError;
+
+    fn try_from(tm: &TypeMeta) -> Result<Self, Self::Error> {
+        Ok(GroupVersion::from_str(&tm.api_version)?.with_kind(&tm.kind))
+    }
+}
+impl TryFrom<TypeMeta> for GroupVersionKind {
+    type Error = ParseGroupVersionError;
+
+    fn try_from(tm: TypeMeta) -> Result<Self, Self::Error> {
+        Ok(GroupVersion::from_str(&tm.api_version)?.with_kind(&tm.kind))
+    }
+}
+
 /// Core information about a family of API Resources
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Eq, Hash)]
 pub struct GroupVersion {
@@ -47,6 +63,15 @@ impl GroupVersion {
         let group = group_.to_string();
         Self { group, version }
     }
+
+    /// Upgrade a GroupVersion to a GroupVersionKind
+    pub fn with_kind(self, kind: &str) -> GroupVersionKind {
+        GroupVersionKind {
+            group: self.group,
+            version: self.version,
+            kind: kind.into(),
+        }
+    }
 }
 
 impl FromStr for GroupVersion {
@@ -118,3 +143,24 @@ impl GroupVersionResource {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    #[test]
+    fn gvk_yaml() {
+        use crate::{GroupVersionKind, TypeMeta};
+        let input = r#"---
+apiVersion: kube.rs/v1
+kind: Example
+metadata:
+  name: doc1
+"#;
+        let tm: TypeMeta = serde_yaml::from_str(input).unwrap();
+        let gvk = GroupVersionKind::try_from(&tm).unwrap(); // takes ref
+        let gvk2: GroupVersionKind = tm.try_into().unwrap(); // takes value
+        assert_eq!(gvk.kind, "Example");
+        assert_eq!(gvk.group, "kube.rs");
+        assert_eq!(gvk.version, "v1");
+        assert_eq!(gvk.kind, gvk2.kind);
+    }
+}
