@@ -14,6 +14,8 @@
 #[cfg(feature = "admission")]
 pub mod admission;
 
+pub mod conversion;
+
 pub mod discovery;
 
 pub mod dynamic;
@@ -37,7 +39,10 @@ pub mod request;
 pub use request::Request;
 
 mod resource;
-pub use resource::{Resource, ResourceExt};
+pub use resource::{
+    ClusterResourceScope, DynamicResourceScope, NamespaceResourceScope, Resource, ResourceExt, ResourceScope,
+    SubResourceScope,
+};
 
 pub mod response;
 pub use response::Status;
